@@ -8,7 +8,7 @@ role PDF::Action::GoTo
     does PDF::Action {
 
     # see [PDF 1.7 TABLE 8.49 Additional entries specific to a go-to action]
-    use PDF::DAO::Tie;
+    use PDF::COS::Tie;
 
     has $.D is entry(:required, :alias<destination>);    #| (Required) The destination to jump to (see Section 8.2.1, “Destinations”).
 
